pub struct LayeredFs { /* private fields */ }Expand description
A filesystem that will delegate most operation to a base one, but have a number of top level directory that points to other filesystems.
Implementations
Sourceimpl LayeredFs
impl LayeredFs
Sourcepub fn new_fs<L>(
locked: &mut Locked<L>,
kernel: &Kernel,
base_fs: FileSystemHandle,
mappings: BTreeMap<FsString, FileSystemHandle>,
) -> FileSystemHandlewhere
L: LockEqualOrBefore<FileOpsCore>,
pub fn new_fs<L>(
locked: &mut Locked<L>,
kernel: &Kernel,
base_fs: FileSystemHandle,
mappings: BTreeMap<FsString, FileSystemHandle>,
) -> FileSystemHandlewhere
L: LockEqualOrBefore<FileOpsCore>,
Build a new filesystem.
base_fs: The base file system that this file system will delegate to.
mappings: The map of top level directory to filesystems that will be layered on top of
base_fs.