pub struct LayeredFsBuilder { /* private fields */ }Expand description
FileSystem builder that allows a set of auxiliary FileSystems to be mounted at specified
paths relative to the base filesystem, regardless of whether the base filesystem has directories
at those paths, that may be mounted-onto.
Auxiliary FileSystems and their mount paths are provided via calls to add(), and the layered
filesystem created using build().
Implementations
Sourceimpl LayeredFsBuilder
impl LayeredFsBuilder
Sourcepub fn new(root_fs: FileSystemHandle) -> Self
pub fn new(root_fs: FileSystemHandle) -> Self
Returns a LayeredFsBuilder with root_fs as the underlying base filesystem.
Sourcepub fn add(&mut self, path: &str, fs: FileSystemHandle)
pub fn add(&mut self, path: &str, fs: FileSystemHandle)
Specifies that filesystem fs should be mounted at the specified path relative to the
base filesystem.
path must specify an absolute path under the base filesystem (i.e. starting with “/”).
If path has multiple components then intermediate components must already have been
added to the builder.
Sourcepub fn build<L>(
self,
locked: &mut Locked<L>,
kernel: &Kernel,
) -> (FileSystemHandle, LayeredFsMounts)where
L: LockEqualOrBefore<FileOpsCore>,
pub fn build<L>(
self,
locked: &mut Locked<L>,
kernel: &Kernel,
) -> (FileSystemHandle, LayeredFsMounts)where
L: LockEqualOrBefore<FileOpsCore>,
Returns the new FileSystem handle, and a finalization callback that must be invoked to
set up the subordinate mount points.
The underlying base FileSystem will be returned directly if no sub-mounts were specified
via add(). Otherwise a LayeredFs instance will be returned, to provide stub directory
entries for the sub-mounts to be mounted onto.