LayeredFsMounts

Type Alias LayeredFsMounts 

pub type LayeredFsMounts = Box<dyn FnOnce(&mut Locked<Unlocked>, &CurrentTask) -> Result<(), Errno>>;
A callback used to complete the initialization of a LayeredFs.

After the FileSystem has been created by LayeredFsBuilder::build, this closure must be invoked to create the sub-mounts that layer the additional filesystems at their specified paths.

Aliased Type

pub struct LayeredFsMounts(/* private fields */);